@@ -1,6 +1,6 @@
 package Hubot::Adapter::Irc;
 {
-  $Hubot::Adapter::Irc::VERSION = '0.0.2';
+  $Hubot::Adapter::Irc::VERSION = '0.0.3';
 }
 use Moose;
 use namespace::autoclean;
@@ -39,7 +39,6 @@ sub join {
     $self->irc->send_srv( JOIN => $channel );
 }
 sub part       { }
-sub createUser { }
 sub kick       { }
 sub command    { }
 
@@ -103,24 +102,17 @@ sub run {
         join => sub {
             my ( $cl, $nick, $channel, $is_myself ) = @_;
             print "joined $channel\n";
-            $self->receive( new Hubot::EnterMessage );
+            my $user = $self->createUser($channel, $nick);
+            $self->receive(
+                new Hubot::EnterMessage(
+                    user => $user
+                )
+            );
         },
         publicmsg => sub {
             my ( $cl, $channel, $ircmsg ) = @_;
             my ( $nick, $msg ) = $self->parse_msg($ircmsg);
-            my $user = $self->userForName($nick);
-            unless ($user) {
-                my $id = time;
-                $id =~ s/\.//;
-                $user = $self->userForId(
-                    $id,
-                    {
-                        name => $nick,
-                        room => $channel,
-                    }
-                );
-            }
-
+            my $user = $self->createUser($channel, $nick);
             $self->receive(
                 new Hubot::TextMessage(
                     user => $user,
@@ -156,6 +148,24 @@ sub close {
     $self->cv->send;
 }
 
+sub createUser {
+    my ($self, $channel, $from) = @_;
+    my $user = $self->userForName($from);
+    unless ($user) {
+        my $id = time;
+        $id =~ s/\.//;
+        $user = $self->userForId(
+            $id,
+            {
+                name => $from,
+                room => $channel,
+            }
+        );
+    }
+
+    return $user;
+}
+
 sub checkCanStart {
     my $self = shift;
 
