@@ -1,6 +1,6 @@
 package Hubot::Adapter::Shell;
 {
-  $Hubot::Adapter::Shell::VERSION = '0.0.2';
+  $Hubot::Adapter::Shell::VERSION = '0.0.3';
 }
 use Moose;
 use namespace::autoclean;
@@ -29,7 +29,7 @@ has 'cv' => (
 
 sub _build_cv { AnyEvent->condvar }
 
-sub close { exit }
+sub close { shift->cv->send }
 
 sub send {
     my ( $self, $user, @strings ) = @_;
@@ -85,6 +85,7 @@ sub run {
     );
 
     $self->cv->recv;
+    exit;
 }
 
 __PACKAGE__->meta->make_immutable;
